GoHook

package module
v0.0.0-...-f9ed9b4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 21, 2018 License: MIT Imports: 5 Imported by: 0

README

GoHook

GoHook is an extremely simple library for creating and sending discord Webhooks in Golang.
Please Read The Information Section

alt text

alt text

Installation

go get github.com/Aaron-JM/GoHook

Update

Gohook now supports basic embbeding, including: Coloring, Title and Description

GoHook.Embed(url, "15258703", "Title", "Description")

Information

Gohook is currently only capable of sending simple content and cannot yet send embedded messages. Although it is possible for users to simply utilize three Grave accent to create an embedded message. Support for embedded messages will be implemented as soon as possible. Also, GoHook does not currently utilize optional parameters therefore it is required that users leave a blank string if they do not wish to alter a certain section. The easiest way to do this would be the following. var null = *new(string). Creating an empty string within null allows for you to leave a certain option empty e.g.

alt text

alt text

ToDo

  • Function For Basic Messages.
  • Function For Embedded Messages.
  • Add Optional Params

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Embed

func Embed(url string, color string, title string, desc string) bool

Embedded Message Section

func Message

func Message(url string, username string, avatar string, input string) bool

Basic Message Function

Types

This section is empty.

Jump to